==> open-xchange-saml-ucs_7.10.1.orig.tar.bz2: open-xchange-saml-ucs-7.10.1/com.openexchange.saml.ucs/src/com/openexchange/saml/ucs/impl/UCSSamlExceptionHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.saml.ucs.impl;

import java.io.IOException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.exception.OXException;
import com.openexchange.saml.spi.ExceptionHandler;
import com.openexchange.tools.servlet.http.Tools;


/**
 * {@link UCSSamlExceptionHandler}
 *
 * @author <a href="mailto:felix.marx@open-xchange.com">Felix Marx</a>
 * @since v7.8.1
 */
public class UCSSamlExceptionHandler implements ExceptionHandler {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(UCSSamlExceptionHandler.class);

    private final String redirectUri;
    private final String failureLogoutRedirectUrl;

    /**
     * Initializes a new {@link UCSSamlExceptionHandler}.
     *
     * @param redirectUri The redirect URI
     * @param failureLogoutRedirectUrl
     */
    public UCSSamlExceptionHandler(String redirectUri, String failureLogoutRedirectUrl) {
        super();
        this.redirectUri = redirectUri;
        this.failureLogoutRedirectUrl = failureLogoutRedirectUrl;
    }

    @Override
    public void handleAuthnResponseFailed(HttpServletRequest httpRequest, HttpServletResponse httpResponse, OXException exception) {
        sendRedirect(httpRequest, httpResponse, exception, redirectUri);
    }

    @Override
    public void handleLogoutResponseFailed(HttpServletRequest httpRequest, HttpServletResponse httpResponse, OXException exception) {
        sendRedirect(httpRequest, httpResponse, exception, failureLogoutRedirectUrl);
    }

    private void sendRedirect(HttpServletRequest httpRequest, HttpServletResponse httpResponse, OXException exception, String redirectUri) {
        Tools.disableCaching(httpResponse);
        try {
            httpResponse.sendRedirect(redirectUri);
            LOG.debug("Sent redirect to {} due to {}", redirectUri, exception.getMessage());
        } catch (IOException e) {
            LOG.error("Caught error while trying to send redirect", e);
            try {
                httpResponse.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
            } catch (IOException x) {
                // nothing to do here
                LOG.error("Caught error while trying to send error after failing to send redirect", x);
            } catch (IllegalStateException x) {
                // nothing to do here
                LOG.error("Caught error while trying to send error after failing to send redirect", x);
            }
        }
    }

}

==> open-xchange-saml-ucs_7.10.2.orig.tar.bz2: open-xchange-saml-ucs-7.10.2/com.openexchange.saml.ucs/src/com/openexchange/saml/ucs/impl/UCSSamlExceptionHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.saml.ucs.impl;

import java.io.IOException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.exception.OXException;
import com.openexchange.saml.spi.ExceptionHandler;
import com.openexchange.tools.servlet.http.Tools;


/**
 * {@link UCSSamlExceptionHandler}
 *
 * @author <a href="mailto:felix.marx@open-xchange.com">Felix Marx</a>
 * @since v7.8.1
 */
public class UCSSamlExceptionHandler implements ExceptionHandler {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(UCSSamlExceptionHandler.class);

    private final String redirectUri;
    private final String failureLogoutRedirectUrl;

    /**
     * Initializes a new {@link UCSSamlExceptionHandler}.
     *
     * @param redirectUri The redirect URI
     * @param failureLogoutRedirectUrl
     */
    public UCSSamlExceptionHandler(String redirectUri, String failureLogoutRedirectUrl) {
        super();
        this.redirectUri = redirectUri;
        this.failureLogoutRedirectUrl = failureLogoutRedirectUrl;
    }

    @Override
    public void handleAuthnResponseFailed(HttpServletRequest httpRequest, HttpServletResponse httpResponse, OXException exception) {
        sendRedirect(httpResponse, exception, redirectUri);
    }

    @Override
    public void handleLogoutResponseFailed(HttpServletRequest httpRequest, HttpServletResponse httpResponse, OXException exception) {
        sendRedirect(httpResponse, exception, failureLogoutRedirectUrl);
    }

    private void sendRedirect(HttpServletResponse httpResponse, OXException exception, String redirectUri) {
        Tools.disableCaching(httpResponse);
        try {
            httpResponse.sendRedirect(redirectUri);
            LOG.debug("Sent redirect to {} due to {}", redirectUri, exception.getMessage());
        } catch (IOException e) {
            LOG.error("Caught error while trying to send redirect", e);
            try {
                httpResponse.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
            } catch (IOException x) {
                // nothing to do here
                LOG.error("Caught error while trying to send error after failing to send redirect", x);
            } catch (IllegalStateException x) {
                // nothing to do here
                LOG.error("Caught error while trying to send error after failing to send redirect", x);
            }
        }
    }

}
